Slice accessors for the CSR index.
Provides read-only access to the underlying arrays for OLAP snapshot cloning and other consumers that need direct array access.
Slice accessors for the CSR index.
Provides read-only access to the underlying arrays for OLAP snapshot cloning and other consumers that need direct array access.