pub struct LabelStats {
pub edge_count: usize,
pub distinct_sources: usize,
pub distinct_targets: usize,
}Expand description
Per-label edge statistics.
Fields
edge_count: usizeNumber of edges with this label.
distinct_sources: usizeNumber of distinct source nodes that have this label on an outbound edge.
distinct_targets: usizeNumber of distinct destination nodes that have this label on an inbound edge.